function [t,X] = Simulate(xdot, t, x0, u, p)
% SIMULATE Simulates the system with a finer time-grid using zero-order hold
%
%   [T,X] = SIMULATE(XDOT,T,X0,U,P) given a function handle XDOT with signature
%
%         X_dot = XDOT(t,x,u,p),    x(0) = x0
%
%     generates time-nodes T = (t_0,...,t_N) with N = 25*size(u,2) and t_N = t(end),
%     to simulate the system with u(t) = u(t_n) (t \in [t_n,t_n+25]) in order
%     to obtain a smoother/realistic state trajectory from a OCP solution
%

    % AUXILIARY VARIABLES
    tf = t(end);
    N  = size(u,2) * 50;
    dT = tf/N;
    t = (0:N-1)*dT;

    % Simulation loop (using RK4)
    X = zeros(size(x0,1), N); X(:,1) = [x0];
    for n = 1:N-1 
        X(:,n+1) = rk4fnc(xdot, dT, X(:,n), u(:,1+floor(n/50)), p);
    end

end