function xplus = rk4fnc(xdot,dt,x,u,p)
% RK4FNC Computes a 4th Order Range-Kutta integration step using a function handle
%
%   XPLUS = RK4FNC(XDOT,DT,X,U,P) given a function handle XDOT with signature
%         X_dot = XDOT(t,x,u,p)
%     computes the RK4 integration step for a time interval (DT), given current
%     state (X), current controls (U), and set of parameters (P).
%

    k1 = xdot([], x            , u, p);
    k2 = xdot([], x + dt/2 * k1, u, p);
    k3 = xdot([], x + dt/2 * k2, u, p);
    k4 = xdot([], x + dt   * k3, u, p);

    xplus = x + dt/6 * (k1 + 2*k2 + 2*k3 + k4);

% --
end